import 'dart:html' as html;
import 'package:stagexl/stagexl.dart';

class SvgDisplayObject extends DisplayObject {

  RenderTexture _renderTexture;
  RenderTextureQuad _renderTextureQuad;

  SvgDisplayObject(String data) {
    var blob = new html.Blob([data], "image/svg+xml;charset=utf-8");
    var url = html.Url.createObjectUrlFromBlob(blob);
    var imageElement = new html.ImageElement();
    imageElement.src = url;
    imageElement.onLoad.listen((e) {
      html.Url.revokeObjectUrl(url);
      _renderTexture = new RenderTexture.fromImage(imageElement, 1.0);
      _renderTextureQuad = _renderTexture.quad;
    });
  }

  render(RenderState renderState) {
    if (_renderTextureQuad != null) {
      renderState.renderQuad(_renderTextureQuad);
    }
  }
}


void main() {

  var canvas = html.querySelector('#stage');
  var stage = new Stage(canvas, webGL: true);
  var renderLoop = new RenderLoop();
  renderLoop.addStage(stage);

  var resourceManager = new ResourceManager();
  resourceManager.addTextFile("camera", "svg/camera.svg");
  resourceManager.addTextFile("car", "svg/car.svg");
  resourceManager.addTextFile("ford", "svg/ford.svg");
  resourceManager.addTextFile("gallardo", "svg/gallardo.svg");
  resourceManager.addTextFile("tiger", "svg/tiger.svg");

  resourceManager.load().then((_) {
    var svg =  resourceManager.getTextFile("tiger");
    var svgDisplayObject = new SvgDisplayObject(svg);
    stage.addChild(svgDisplayObject);
  });

}
